integrators.sde package
===========================

.. currentmodule:: integrators.sde
.. automodule:: integrators.sde

.. contents::
    :local:
    :depth: 1


Strong 1.0 Runge-Kutta methods
------------------------------


.. autosummary::
    :toctree: _autosummary

    euler
    milstein
    srk1_strong
    srk2_strong


Weak 2.0 Runge-Kutta methods
----------------------------

.. autosummary::
    :toctree: _autosummary

    srk2_weak
    srk2_weak


Weak 1.5 Runge-Kutta methods for scalar Wiener
----------------------------------------------

.. autosummary::
    :toctree: _autosummary

    srk1w1_scalar
    srk2w1_scalar
    KlPl_scalar

